@@ -102,7 +102,8 @@ gdbm_reorganize (GDBM_FILE dbf)
   new_name[len] = '#';
 
   /* Open the new database. */  
-  new_dbf = gdbm_open (new_name, dbf->header->block_size, GDBM_WRCREAT,
+  new_dbf = gdbm_open (new_name, dbf->header->block_size,
+		       GDBM_WRCREAT | (dbf->cloexec ? GDBM_CLOEXEC : 0),
 		       fileinfo.st_mode, dbf->fatal_err);
 
   if (new_dbf == NULL)
@@ -183,12 +184,6 @@ gdbm_reorganize (GDBM_FILE dbf)
     free (dbf->bucket_cache);
   }
 
-#if HAVE_MMAP
-  /* Re-initialize mapping if required */
-  if (dbf->memory_mapping)
-    _gdbm_mapped_init (dbf);
-#endif
-  
   dbf->desc           = new_dbf->desc;
   dbf->header         = new_dbf->header;
   dbf->dir            = new_dbf->dir;
@@ -202,6 +197,12 @@ gdbm_reorganize (GDBM_FILE dbf)
   dbf->bucket_changed    = new_dbf->bucket_changed;
   dbf->second_changed    = new_dbf->second_changed;
    
+#if HAVE_MMAP
+  /* Re-initialize mapping if required */
+  if (dbf->memory_mapping)
+    _gdbm_mapped_init (dbf);
+#endif
+  
   free (new_dbf->name);   
   free (new_dbf);
   free (new_name);
